@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6585 $
-## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  File version: $Revision: 6801 $
+## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -310,8 +310,11 @@ as.data.frame.PowerAndAverageSampleNumberResult <- function(x, row.names = NULL,
         optional = FALSE, niceColumnNamesEnabled = FALSE, includeAllParameters = FALSE, ...) {
     parameterNames <- x$.getVisibleFieldNames()
     parameterNames <- parameterNames[parameterNames != "nMax"]
-    dataFrame <- .getAsDataFrame(parameterSet = x, parameterNames = parameterNames,
-        niceColumnNamesEnabled = niceColumnNamesEnabled, includeAllParameters = includeAllParameters,
+    dataFrame <- .getAsDataFrame(
+        parameterSet = x, 
+        parameterNames = parameterNames,
+        niceColumnNamesEnabled = niceColumnNamesEnabled, 
+        includeAllParameters = includeAllParameters,
         tableColumnNames = .getTableColumnNames(design = x$.design)
     )
     return(dataFrame)
