@@ -14,21 +14,23 @@
 ## | 
 ## |  Contact us for information about our services: info@rpact.com
 ## | 
-## |  File version: $Revision: 5644 $
-## |  Last changed: $Date: 2021-12-10 14:14:55 +0100 (Fr, 10 Dez 2021) $
+## |  File version: $Revision: 6810 $
+## |  Last changed: $Date: 2023-02-13 12:58:47 +0100 (Mo, 13 Feb 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## | 
 
+#' @include f_core_utilities.R
+NULL
+
 #'
-#' @name SimulationResults_names
-#' 
 #' @title
 #' Names of a Simulation Results Object
 #'
 #' @description
 #' Function to get the names of a \code{\link{SimulationResults}} object.
 #' 
-#' @param x A \code{\link{SimulationResults}} object created by \code{getSimulationResults[MultiArm/Enrichment][Means/Rates/Survival]}.
+#' @param x A \code{\link{SimulationResults}} object created by 
+#' \code{getSimulationResults[MultiArm/Enrichment][Means/Rates/Survival]}.
 #' 
 #' @details
 #' Returns the names of a simulation results that can be accessed by the user.
@@ -57,6 +59,9 @@ names.SimulationResults <- function(x) {
 #' @description
 #' A class for simulation results.
 #' 
+#' @template field_seed
+#' @template field_iterations
+#' 
 #' @details 
 #' \code{SimulationResults} is the basic class for 
 #' \itemize{
@@ -190,10 +195,10 @@ SimulationResults <- setRefClass("SimulationResults",
 							"eventsPerStage1",
 							"eventsPerStage2",
 							"eventsPerStage",
-							"testStatistic",
-							"logRankStatistic",
-							"hazardRatioEstimateLR")
-					}
+                            "testStatistic",
+                            "logRankStatistic",
+                            "hazardRatioEstimateLR")
+                    }
 					else if (inherits(.self, "SimulationResultsMultiArmMeans") || 
 							inherits(.self, "SimulationResultsMultiArmRates")) {
 						params <- c(
@@ -242,25 +247,8 @@ SimulationResults <- setRefClass("SimulationResults",
 					
 					stages <- sort(unique(.self$.data$stageNumber))
 					
-					variedParameterName1 <- NA_character_
-					variedParameterName2 <- NA_character_
-					if (inherits(.self, "SimulationResultsMeans")) {
-						variedParameterName1 <- "alternative"
-					} else if (inherits(.self, "SimulationResultsRates") || inherits(.self, "SimulationResultsSurvival")) {
-						variedParameterName1 <- "pi1"
-					} else if (grepl("MultiArm", class(.self))) {
-						if (inherits(.self, "SimulationResultsMultiArmMeans")) {
-							variedParameterName1 <- "muMax"
-						}
-						else if (inherits(.self, "SimulationResultsMultiArmRates")) {
-							variedParameterName1 <- "piMax"
-						}
-						else if (inherits(.self, "SimulationResultsMultiArmSurvival")) {
-							variedParameterName1 <- "omegaMax"
-						}
-						variedParameterName2 <- "armNumber"
-					}
-					
+					variedParameterName1 <- .getVariedParameterName(1)
+					variedParameterName2 <- .getVariedParameterName(2)
 					parameterValues1 <- .getVariedParameterValues(variedParameterName1)
 					parameterValues2 <- .getVariedParameterValues(variedParameterName2)
 					
@@ -316,7 +304,7 @@ SimulationResults <- setRefClass("SimulationResults",
 				
 				twoGroupsEnabled <- !inherits(.self, "SimulationResultsMeans")
 				multiArmSurvivalEnabled <- inherits(.self, "SimulationResultsMultiArmSurvival")
-				enrichmentEnabled <- grepl("SimulationResultsEnrichment", class(.self))
+				enrichmentEnabled <- grepl("SimulationResultsEnrichment", .getClassName(.self))
 				
 				if (.design$kMax > 1 || twoGroupsEnabled || multiArmSurvivalEnabled) {
 					
@@ -354,6 +342,36 @@ SimulationResults <- setRefClass("SimulationResults",
 			}
 		},
 		
+		.getVariedParameterName = function(number = 1) {
+            if (number == 2) {
+               if (!inherits(.self, "SimulationResultsMeans") &&
+                        !inherits(.self, "SimulationResultsRates") && 
+                        !inherits(.self, "SimulationResultsSurvival") &&
+                        grepl("MultiArm", .getClassName(.self))) {
+                    return("armNumber")
+                }
+                return(NA_character_)
+            }
+            
+            variedParameterName1 <- NA_character_
+            if (inherits(.self, "SimulationResultsMeans")) {
+                variedParameterName1 <- "alternative"
+            } else if (inherits(.self, "SimulationResultsRates") || inherits(.self, "SimulationResultsSurvival")) {
+                variedParameterName1 <- "pi1"
+            } else if (grepl("MultiArm", .getClassName(.self))) {
+                if (inherits(.self, "SimulationResultsMultiArmMeans")) {
+                    variedParameterName1 <- "muMax"
+                }
+                else if (inherits(.self, "SimulationResultsMultiArmRates")) {
+                    variedParameterName1 <- "piMax"
+                }
+                else if (inherits(.self, "SimulationResultsMultiArmSurvival")) {
+                    variedParameterName1 <- "omegaMax"
+                }
+            }
+			return(variedParameterName1)
+		},
+		
 		.getVariedParameterValues = function(variedParameterName) {
 			if (is.na(variedParameterName)) {
 				return(NA_real_)
@@ -441,11 +459,11 @@ SimulationResults <- setRefClass("SimulationResults",
 		.toString = function(startWithUpperCase = FALSE) {
 			s <- "simulation of"
 			
-			if (grepl("MultiArm", class(.self)) && !is.null(.self[["activeArms"]]) && .self$activeArms > 1) {
+			if (grepl("MultiArm", .getClassName(.self)) && !is.null(.self[["activeArms"]]) && .self$activeArms > 1) {
 				s <- paste(s, "multi-arm")
 			}
 			
-			if (grepl("Enrichment", class(.self)) && !is.null(.self[["populations"]]) && .self$populations > 1) {
+			if (grepl("Enrichment", .getClassName(.self)) && !is.null(.self[["populations"]]) && .self$populations > 1) {
 				s <- paste(s, "enrichment")
 			}
 			
@@ -484,7 +502,9 @@ SimulationResults <- setRefClass("SimulationResults",
 		.getParametersToShow = function() {
 			parametersToShow <- .getVisibleFieldNames()
 			y <- c(
-				"iterations",
+                "eventsPerStage",
+                "overallEventsPerStage", 
+                "iterations",
 				"overallReject",  # base
 				"rejectAtLeastOne",
 				"rejectPerStage",
@@ -505,7 +525,6 @@ SimulationResults <- setRefClass("SimulationResults",
 				"expectedNumberOfSubjects",
 				"expectedNumberOfEvents",
 				"sampleSizes",
-				"eventsPerStage",
 				"singleNumberOfEventsPerStage",
 				"conditionalPowerAchieved" # base
 			)
@@ -515,7 +534,13 @@ SimulationResults <- setRefClass("SimulationResults",
 		
 		.isSampleSizeObject = function() {
 			return(FALSE)
-		}
+		},
+        
+        getRawDataResults = function(maxNumberOfIterations = NA_integer_) {
+            return(.getSimulationParametersFromRawData(.self$.data, 
+                variantName = .getVariedParameterName(),
+                maxNumberOfIterations = maxNumberOfIterations))
+        }
 	)
 )
 
@@ -528,8 +553,7 @@ SimulationResultsBaseMeans <- setRefClass("SimulationResultsBaseMeans",
 		maxNumberOfSubjectsPerStage = "numeric",
 		thetaH1 = "numeric",
 		stDevH1 = "numeric",
-		calcSubjectsFunction = "function",
-		
+		calcSubjectsFunction = "ANY",
 		expectedNumberOfSubjects = "numeric"
 	),
 	methods = list(
@@ -562,8 +586,12 @@ SimulationResultsBaseMeans <- setRefClass("SimulationResultsBaseMeans",
 #' @description
 #' A class for simulation results means.
 #' 
+#' @field groups The number of groups. Is an integer vector of length 1.
+#' @template field_directionUpper
+#' @template field_normalApproximation
+#' 
 #' @details 
-#' Use \code{\link{getSimulationMeans}} to create an object of this type.
+#' Use \code{\link[=getSimulationMeans]{getSimulationMeans()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -586,9 +614,6 @@ SimulationResultsMeans <- setRefClass("SimulationResultsMeans",
 		groups = "integer",
 		directionUpper = "logical",
 		
-		thetaH1 = "numeric",
-		srDevH1 = "numeric",
-		
 		effect = "numeric",
 		earlyStop = "numeric",
 		sampleSizes = "matrix",		
@@ -614,7 +639,7 @@ SimulationResultsMeans <- setRefClass("SimulationResultsMeans",
 #' A class for simulation results means in multi-arm designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationMultiArmMeans}} to create an object of this type.
+#' Use \code{\link[=getSimulationMultiArmMeans]{getSimulationMultiArmMeans()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -678,8 +703,7 @@ SimulationResultsBaseRates <- setRefClass("SimulationResultsBaseRates",
 		plannedSubjects = "numeric", 
 		minNumberOfSubjectsPerStage = "numeric",
 		maxNumberOfSubjectsPerStage = "numeric",
-		calcSubjectsFunction = "function",
-		
+		calcSubjectsFunction = "ANY",
 		expectedNumberOfSubjects = "numeric"
 	),
 	methods = list(
@@ -713,8 +737,12 @@ SimulationResultsBaseRates <- setRefClass("SimulationResultsBaseRates",
 #' @description
 #' A class for simulation results rates.
 #' 
+#' @field groups The number of groups. Is an integer vector of length 1.
+#' @template field_directionUpper
+#' @template field_normalApproximation
+#' 
 #' @details 
-#' Use \code{\link{getSimulationRates}} to create an object of this type.
+#' Use \code{\link[=getSimulationRates]{getSimulationRates()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -784,7 +812,7 @@ SimulationResultsRates <- setRefClass("SimulationResultsRates",
 #' A class for simulation results rates in multi-arm designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationMultiArmRates}} to create an object of this type.
+#' Use \code{\link[=getSimulationMultiArmRates]{getSimulationMultiArmRates()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -805,7 +833,7 @@ SimulationResultsMultiArmRates <- setRefClass("SimulationResultsMultiArmRates",
 		typeOfShape = "character",
 		piMaxVector = "numeric", 
 		piControl = "numeric", 
-		piH1 = "numeric", 
+        piTreatmentsH1 = "numeric", 
 		piControlH1 = "numeric", 
 		gED50 = "numeric",
 		slope = "numeric",
@@ -852,8 +880,7 @@ SimulationResultsBaseSurvival <- setRefClass("SimulationResultsBaseSurvival",
 		minNumberOfEventsPerStage = "numeric",
 		maxNumberOfEventsPerStage = "numeric", 
 		thetaH1 = "numeric",
-		calcEventsFunction = "function", 
-		
+		calcEventsFunction = "ANY", 
 		expectedNumberOfEvents = "numeric"
 	),
 	methods = list(
@@ -887,7 +914,7 @@ SimulationResultsBaseSurvival <- setRefClass("SimulationResultsBaseSurvival",
 #' A class for simulation results survival.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationSurvival}} to create an object of this type.
+#' Use \code{\link[=getSimulationSurvival]{getSimulationSurvival()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -934,7 +961,8 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
 			numberOfSubjects1 = "matrix",
 			numberOfSubjects2 = "matrix",
 			eventsPerStage = "matrix", 
-			expectedNumberOfSubjects = "numeric", 
+            overallEventsPerStage = "matrix",
+            expectedNumberOfSubjects = "numeric", 
 			rejectPerStage = "matrix",
 			overallReject = "numeric",		
 			conditionalPowerAchieved = "matrix"
@@ -982,7 +1010,7 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
 #' A class for simulation results survival in multi-arm designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationMultiArmSurvival}} to create an object of this type.
+#' Use \code{\link[=getSimulationMultiArmSurvival]{getSimulationMultiArmSurvival()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -1051,7 +1079,7 @@ SimulationResultsMultiArmSurvival <- setRefClass("SimulationResultsMultiArmSurvi
 #' A class for simulation results means in enrichment designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationEnrichmentMeans}} to create an object of this type.
+#' Use \code{\link[=getSimulationEnrichmentMeans]{getSimulationEnrichmentMeans()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -1115,7 +1143,7 @@ SimulationResultsEnrichmentMeans <- setRefClass("SimulationResultsEnrichmentMean
 #' A class for simulation results rates in enrichment designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationEnrichmentRates}} to create an object of this type.
+#' Use \code{\link[=getSimulationEnrichmentRates]{getSimulationEnrichmentRates()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -1145,7 +1173,7 @@ SimulationResultsEnrichmentRates <- setRefClass("SimulationResultsEnrichmentRate
 		epsilonValue = "numeric", 
 		rValue = "numeric",
 		threshold = "numeric",		
-		selectArmsFunction = "function",
+		selectPopulationsFunction = "function",
 		earlyStop = "matrix",
 		selectedPopulations = "array",
 		numberOfPopulations = "matrix",
@@ -1181,7 +1209,7 @@ SimulationResultsEnrichmentRates <- setRefClass("SimulationResultsEnrichmentRate
 #' A class for simulation results survival in enrichment designs.
 #' 
 #' @details 
-#' Use \code{\link{getSimulationEnrichmentSurvival}} to create an object of this type.
+#' Use \code{\link[=getSimulationEnrichmentSurvival]{getSimulationEnrichmentSurvival()}} to create an object of this type.
 #' 
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -1209,7 +1237,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 		epsilonValue = "numeric", 
 		rValue = "numeric",
 		threshold = "numeric",		
-		selectArmsFunction = "function",
+		selectPopulationsFunction = "function",
 		correlationComputation = "character",
 		earlyStop = "matrix",
 		selectedPopulations = "array",
@@ -1269,17 +1297,17 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 }
 
 .getSimulationPlotXAxisParameterName <- function(simulationResults, showSource = FALSE, simulationResultsName = NA_character_) {
-	if (grepl("SimulationResultsEnrichment", class(simulationResults))) {
+	if (grepl("SimulationResultsEnrichment", .getClassName(simulationResults))) {
 		effectDataList <- .getSimulationEnrichmentEffectData(simulationResults)
 		if (ncol(effectDataList$effectData) == 1) {
-			if (showSource) {
+			if (!isFALSE(showSource)) {
 				return(paste0(simulationResultsName, "$effectList$", effectDataList$effectMatrixName, "[, 1]"))
 			}
 			
 			return(sub("s$", "", effectDataList$effectMatrixName))
 		}
 		
-		if (showSource) {
+		if (!isFALSE(showSource)) {
 			numberOfSituations <- nrow(simulationResults$effectList[[effectDataList$effectMatrixName]])
 			return(paste0("c(1:", numberOfSituations, ")"))
 		}
@@ -1287,10 +1315,10 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 		return("situation")
 	}
 	
-	survivalEnabled <- grepl("Survival", class(simulationResults))
-	meansEnabled <- grepl("Means", class(simulationResults))
-	if (grepl("MultiArm", class(simulationResults))) {
-		if (showSource) {
+	survivalEnabled <- grepl("Survival", .getClassName(simulationResults))
+	meansEnabled <- grepl("Means", .getClassName(simulationResults))
+	if (grepl("MultiArm", .getClassName(simulationResults))) {
+		if (!isFALSE(showSource)) {
 			gMax <- nrow(simulationResults$effectMatrix)
 			return(paste0(simulationResultsName, "$effectMatrix[", gMax, ", ]"))
 		}
@@ -1298,7 +1326,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 		return("effectMatrix")
 	}
 	
-	if (grepl("Survival", class(simulationResults))) {
+	if (grepl("Survival", .getClassName(simulationResults))) {
 		return("hazardRatio")
 	}	
 	
@@ -1306,7 +1334,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 }
 
 .getSimulationPlotXAxisLabel <- function(simulationResults, xlab = NULL) {
-	if (grepl("SimulationResultsEnrichment", class(simulationResults))) {
+	if (grepl("SimulationResultsEnrichment", .getClassName(simulationResults))) {
 		effectDataList <- .getSimulationEnrichmentEffectData(simulationResults)
 		if (ncol(effectDataList$effectData) == 1) {
 			xLabel <- simulationResults$.parameterNames[[effectDataList$effectMatrixName]]
@@ -1316,7 +1344,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 		return("Situation")
 	}
 	
-	multiArmEnabled <- grepl("MultiArm", class(simulationResults))
+	multiArmEnabled <- grepl("MultiArm", .getClassName(simulationResults))
 	userDefinedEffectMatrix <- multiArmEnabled && simulationResults$.getParameterType("effectMatrix") == C_PARAM_USER_DEFINED
 	if (!is.null(xlab) && !is.na(xlab)) {
 		return(xlab)
@@ -1404,10 +1432,10 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 		plotSettings <- simulationResults$.plotSettings
 	}
 	
-	survivalEnabled <- grepl("Survival", class(simulationResults))
-	meansEnabled <- grepl("Means", class(simulationResults))
-	multiArmEnabled <- grepl("MultiArm", class(simulationResults))
-	enrichmentEnabled <- grepl("Enrichment", class(simulationResults))
+	survivalEnabled <- grepl("Survival", .getClassName(simulationResults))
+	meansEnabled <- grepl("Means", .getClassName(simulationResults))
+	multiArmEnabled <- grepl("MultiArm", .getClassName(simulationResults))
+	enrichmentEnabled <- grepl("Enrichment", .getClassName(simulationResults))
 	userDefinedEffectMatrix <- multiArmEnabled && simulationResults$.getParameterType("effectMatrix") == C_PARAM_USER_DEFINED
 	
 	gMax <- NA_integer_
@@ -2072,7 +2100,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 #' Simulation Results Plotting
 #' 
 #' @param x The simulation results, obtained from \cr
-#'        \code{\link{getSimulationSurvival}}.
+#'        \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}.
 #' @param y Not available for this kind of plot (is only defined to be compatible to the generic plot function).
 #' @param main The main title.
 #' @param xlab The x-axis label.
@@ -2086,9 +2114,9 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 #' @inheritParams param_grid
 #' @param type The plot type (default = \code{1}). The following plot types are available:
 #' \itemize{
-#'   \item \code{1}: creates a 'Overall Success' plot (multi-arm only)
-#'   \item \code{2}: creates a 'Success per Stage' plot (multi-arm only)
-#'   \item \code{3}: creates a 'Selected Arms per Stage' plot (multi-arm only)
+#'   \item \code{1}: creates a 'Overall Success' plot (multi-arm and enrichment only)
+#'   \item \code{2}: creates a 'Success per Stage' plot (multi-arm and enrichment  only)
+#'   \item \code{3}: creates a 'Selected Arms per Stage' plot (multi-arm and enrichment  only)
 #'   \item \code{4}: creates a 'Reject per Stage' or 'Rejected Arms per Stage' plot
 #'   \item \code{5}: creates a 'Overall Power and Early Stopping' plot
 #'   \item \code{6}: creates a 'Expected Number of Subjects and Power / Early Stop' or 
@@ -2096,11 +2124,11 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 #'   \item \code{7}: creates an 'Overall Power' plot
 #'   \item \code{8}: creates an 'Overall Early Stopping' plot
 #'   \item \code{9}: creates an 'Expected Sample Size' or 'Expected Number of Events' plot
-#'   \item \code{10}: creates a 'Study Duration' plot (non-multi-arm survival only)
-#'   \item \code{11}: creates an 'Expected Number of Subjects' plot (non-multi-arm survival only)
-#'   \item \code{12}: creates an 'Analysis Times' plot (non-multi-arm survival only)
-#'   \item \code{13}: creates a 'Cumulative Distribution Function' plot (non-multi-arm survival only)
-#'   \item \code{14}: creates a 'Survival Function' plot (non-multi-arm survival only)
+#'   \item \code{10}: creates a 'Study Duration' plot (non-multi-arm and non-enrichment survival only)
+#'   \item \code{11}: creates an 'Expected Number of Subjects' plot (non-multi-arm and non-enrichment survival only)
+#'   \item \code{12}: creates an 'Analysis Times' plot (non-multi-arm and non-enrichment survival only)
+#'   \item \code{13}: creates a 'Cumulative Distribution Function' plot (non-multi-arm and non-enrichment survival only)
+#'   \item \code{14}: creates a 'Survival Function' plot (non-multi-arm and non-enrichment survival only)
 #'   \item \code{"all"}: creates all available plots and returns it as a grid plot or list
 #' }
 #' @inheritParams param_three_dots_plot
@@ -2114,7 +2142,7 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
 #' @template return_object_ggplot
 #' 
 #' @examples 
-#' \donttest{
+#' \dontrun{
 #' results <- getSimulationMeans(alternative = 0:4, stDev = 5, 
 #'     plannedSubjects = 40, maxNumberOfIterations = 1000)
 #' plot(results, type = 5)
@@ -2130,6 +2158,7 @@ plot.SimulationResults <- function(x, y, ..., main = NA_character_,
 		
 	fCall = match.call(expand.dots = FALSE)
 	simulationResultsName <- deparse(fCall$x)
+    .assertGgplotIsInstalled()
 	.assertIsSingleInteger(grid, "grid", validateType = FALSE)
 	typeNumbers <- .getPlotTypeNumber(type, x)
 	if (is.null(plotSettings)) {
@@ -2166,8 +2195,6 @@ plot.SimulationResults <- function(x, y, ..., main = NA_character_,
 }
 
 #'
-#' @name SimulationResults_print
-#' 
 #' @title
 #' Print Simulation Results
 #' 
@@ -2203,13 +2230,13 @@ print.SimulationResults <- function(x, ..., showStatistics = FALSE, markdown = F
 #' @description
 #' Returns the aggregated simulation data.
 #' 
-#' @param x A \code{\link{SimulationResults}} object created by \code{\link{getSimulationMeans}},\cr 
-#'  \code{\link{getSimulationRates}}, \code{\link{getSimulationSurvival}}, \code{\link{getSimulationMultiArmMeans}},\cr 
-#'  \code{\link{getSimulationMultiArmRates}}, or \code{\link{getSimulationMultiArmSurvival}}.
+#' @param x A \code{\link{SimulationResults}} object created by \code{\link[=getSimulationMeans]{getSimulationMeans()}},\cr 
+#'  \code{\link[=getSimulationRates]{getSimulationRates()}}, \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}, \code{\link[=getSimulationMultiArmMeans]{getSimulationMultiArmMeans()}},\cr 
+#'  \code{\link[=getSimulationMultiArmRates]{getSimulationMultiArmRates()}}, or \code{\link[=getSimulationMultiArmSurvival]{getSimulationMultiArmSurvival()}}.
 #'
 #' @details
 #' This function can be used to get the aggregated simulated data from an simulation results  
-#' object, for example, obtained by \code{\link{getSimulationSurvival}}.
+#' object, for example, obtained by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}.
 #' In this case, the data frame contains the following columns:
 #' \enumerate{
 #'   \item \code{iterationNumber}: The number of the simulation iteration.
@@ -2243,8 +2270,8 @@ print.SimulationResults <- function(x, ..., showStatistics = FALSE, markdown = F
 #'         log-rank statistic.
 
 #' }
-#' A subset of variables is provided for \code{\link{getSimulationMeans}}, \code{\link{getSimulationRates}}, \code{\link{getSimulationMultiArmMeans}},\cr 
-#'  \code{\link{getSimulationMultiArmRates}}, or \code{\link{getSimulationMultiArmSurvival}}.
+#' A subset of variables is provided for \code{\link[=getSimulationMeans]{getSimulationMeans()}}, \code{\link[=getSimulationRates]{getSimulationRates()}}, \code{\link[=getSimulationMultiArmMeans]{getSimulationMultiArmMeans()}},\cr 
+#'  \code{\link[=getSimulationMultiArmRates]{getSimulationMultiArmRates()}}, or \code{\link[=getSimulationMultiArmSurvival]{getSimulationMultiArmSurvival()}}.
 #' 
 #' @template return_dataframe
 #' 
@@ -2350,16 +2377,16 @@ getData.SimulationResults <- function(x) {
 #' @description
 #' Returns the raw survival data which was generated for simulation.
 #' 
-#' @param x An \code{\link{SimulationResults}} object created by \code{\link{getSimulationSurvival}}.
+#' @param x A \code{\link{SimulationResults}} object created by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}.
 #' @param aggregate Logical. If \code{TRUE} the raw data will be aggregated similar to
-#'        the result of \code{\link{getData}}, default is \code{FALSE}.
+#'        the result of \code{\link[=getData]{getData()}}, default is \code{FALSE}.
 #'
 #' @details
-#' This function works only if \code{\link{getSimulationSurvival}} was called with a \cr
+#' This function works only if \code{\link[=getSimulationSurvival]{getSimulationSurvival()}} was called with a \cr
 #' \code{maxNumberOfRawDatasetsPerStage} > 0 (default is \code{0}).
 #' 
 #' This function can be used to get the simulated raw data from a simulation results  
-#' object obtained by \code{\link{getSimulationSurvival}}. Note that \code{\link{getSimulationSurvival}} 
+#' object obtained by \code{\link[=getSimulationSurvival]{getSimulationSurvival()}}. Note that \code{\link[=getSimulationSurvival]{getSimulationSurvival()}} 
 #' must called before with \code{maxNumberOfRawDatasetsPerStage} > 0.
 #' The data frame contains the following columns: 
 #' \enumerate{
@@ -2386,7 +2413,7 @@ getData.SimulationResults <- function(x) {
 #' @template return_dataframe
 #' 
 #' @examples 
-#' \donttest{
+#' \dontrun{
 #' results <- getSimulationSurvival(pi1 = seq(0.3,0.6,0.1), pi2 = 0.3, eventTime = 12, 
 #'     accrualTime = 24, plannedEvents = 40, maxNumberOfSubjects = 200, 
 #'     maxNumberOfIterations = 50, maxNumberOfRawDatasetsPerStage = 5)
