@@ -1,22 +1,22 @@
-#:#
-#:#  *Time classes*
-#:# 
-#:#  This file is part of the R package rpact: 
-#:#  Confirmatory Adaptive Clinical Trial Design and Analysis
-#:# 
-#:#  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
-#:#  Licensed under "GNU Lesser General Public License" version 3
-#:#  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
-#:# 
-#:#  RPACT company website: https://www.rpact.com
-#:#  rpact package website: https://www.rpact.org
-#:# 
-#:#  Contact us for information about our services: info@rpact.com
-#:# 
-#:#  File version: $Revision: 4051 $
-#:#  Last changed: $Date: 2020-11-30 14:42:18 +0100 (Mo, 30 Nov 2020) $
-#:#  Last changed by: $Author: pahlke $
-#:# 
+## |
+## |  *Time classes*
+## | 
+## |  This file is part of the R package rpact: 
+## |  Confirmatory Adaptive Clinical Trial Design and Analysis
+## | 
+## |  Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
+## |  Licensed under "GNU Lesser General Public License" version 3
+## |  License text can be found here: https://www.r-project.org/Licenses/LGPL-3
+## | 
+## |  RPACT company website: https://www.rpact.com
+## |  rpact package website: https://www.rpact.org
+## | 
+## |  Contact us for information about our services: info@rpact.com
+## | 
+## |  File version: $Revision: 6585 $
+## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
+## |  Last changed by: $Author: pahlke $
+## | 
 
 C_REGEXP_GREATER_OR_EQUAL <- ">= ?"
 C_REGEXP_SMALLER <- "< ?"
@@ -168,12 +168,12 @@ TimeDefinition <- setRefClass("TimeDefinition",
 #' @return Returns a \code{\link{PiecewiseSurvivalTime}} object.
 #' The following generics (R generic functions) are available for this result object:
 #' \itemize{
-#'   \item \code{\link[=names.FieldSet]{names}} to obtain the field names,
-#'   \item \code{\link[=print.FieldSet]{print}} to print the object,
-#'   \item \code{\link[=summary.ParameterSet]{summary}} to display a summary of the object,
-#'   \item \code{\link[=plot.ParameterSet]{plot}} to plot the object,
-#'   \item \code{\link[=as.data.frame.ParameterSet]{as.data.frame}} to coerce the object to a \code{\link[base]{data.frame}},
-#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix}} to coerce the object to a \code{\link[base]{matrix}}.
+#'   \item \code{\link[=names.FieldSet]{names()}} to obtain the field names,
+#'   \item \code{\link[=print.FieldSet]{print()}} to print the object,
+#'   \item \code{\link[=summary.ParameterSet]{summary()}} to display a summary of the object,
+#'   \item \code{\link[=plot.ParameterSet]{plot()}} to plot the object,
+#'   \item \code{\link[=as.data.frame.ParameterSet]{as.data.frame()}} to coerce the object to a \code{\link[base]{data.frame}},
+#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}} to coerce the object to a \code{\link[base]{matrix}}.
 #' }
 #' @template how_to_get_help_for_generics
 #' 
@@ -190,12 +190,12 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 		pi2 = NA_real_,
 		median1 = NA_real_,
 		median2 = NA_real_,
-		eventTime = 12L, # C_EVENT_TIME_DEFAULT
+		eventTime = 12, # C_EVENT_TIME_DEFAULT
 		kappa = 1,
 		delayedResponseAllowed = FALSE) {
 		
 	.warnInCaseOfUnknownArguments(functionName = "getPiecewiseSurvivalTime", ..., 
-		ignore = c(".pi1Default", ".lambdaBased", ".silent"))
+		ignore = c(".pi1Default", ".lambdaBased", ".silent"), exceptionEnabled = TRUE)
 	
 	if (inherits(piecewiseSurvivalTime, "TrialDesignPlanSurvival")) {
 		piecewiseSurvivalTime <- piecewiseSurvivalTime$.piecewiseSurvivalTime
@@ -229,8 +229,9 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 	.assertIsSingleNumber(eventTime, "eventTime", naAllowed = TRUE)
 	.assertIsValidKappa(kappa)
 	.assertIsSingleLogical(delayedResponseAllowed, "delayedResponseAllowed")
-	
-	return(PiecewiseSurvivalTime(piecewiseSurvivalTime = piecewiseSurvivalTime, 
+    
+	return(PiecewiseSurvivalTime(
+        piecewiseSurvivalTime = piecewiseSurvivalTime, 
 		lambda1 = lambda1, 
 		lambda2 = lambda2,
 		hazardRatio = hazardRatio,
@@ -252,25 +253,23 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 #' 
 #' @inheritParams param_accrualTime
 #' @inheritParams param_accrualIntensity
+#' @inheritParams param_accrualIntensityType
 #' @param maxNumberOfSubjects The maximum number of subjects.
-#' @param accrualIntensityType A character value specifying the accrual intensity input type.
-#'        Must be one of \code{"auto"}, \code{"absolute"}, or \code{"relative"}; default is \code{"auto"},
-#'        i.e., if all values are < 1 the type is \code{"relative"}, otherwise it is \code{"absolute"}.
 #' @inheritParams param_three_dots
 #' 
 #' @template details_piecewise_accrual
 #' 
-#' @seealso \code{\link{getNumberOfSubjects}} for calculating the number of subjects at given time points. 
+#' @seealso \code{\link[=getNumberOfSubjects]{getNumberOfSubjects()}} for calculating the number of subjects at given time points. 
 #' 
 #' @return Returns an \code{\link{AccrualTime}} object.
 #' The following generics (R generic functions) are available for this result object:
 #' \itemize{
-#'   \item \code{\link[=names.FieldSet]{names}} to obtain the field names,
-#'   \item \code{\link[=print.FieldSet]{print}} to print the object,
-#'   \item \code{\link[=summary.ParameterSet]{summary}} to display a summary of the object,
-#'   \item \code{\link[=plot.ParameterSet]{plot}} to plot the object,
-#'   \item \code{\link[=as.data.frame.ParameterSet]{as.data.frame}} to coerce the object to a \code{\link[base]{data.frame}},
-#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix}} to coerce the object to a \code{\link[base]{matrix}}.
+#'   \item \code{\link[=names.FieldSet]{names()}} to obtain the field names,
+#'   \item \code{\link[=print.FieldSet]{print()}} to print the object,
+#'   \item \code{\link[=summary.ParameterSet]{summary()}} to display a summary of the object,
+#'   \item \code{\link[=plot.ParameterSet]{plot()}} to plot the object,
+#'   \item \code{\link[=as.data.frame.ParameterSet]{as.data.frame()}} to coerce the object to a \code{\link[base]{data.frame}},
+#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}} to coerce the object to a \code{\link[base]{matrix}}.
 #' }
 #' @template how_to_get_help_for_generics
 #'
@@ -280,9 +279,9 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 #' 
 getAccrualTime <- function(accrualTime = NA_real_, 
 		...,
-		accrualIntensity = NA_real_, 
-		maxNumberOfSubjects = NA_real_,
-		accrualIntensityType = c("auto", "absolute", "relative")) {
+		accrualIntensity = NA_real_,
+		accrualIntensityType = c("auto", "absolute", "relative"), 
+		maxNumberOfSubjects = NA_real_) {
 	
 	.warnInCaseOfUnknownArguments(functionName = "getAccrualTime", ..., 
 		ignore = c("showWarnings"))
@@ -343,6 +342,8 @@ getAccrualTime <- function(accrualTime = NA_real_,
 #' 
 #' @include f_core_constants.R
 #' @include class_core_parameter_set.R
+#' @include f_core_utilities.R
+#' @include f_logger.R
 #' 
 #' @keywords internal
 #' 
@@ -724,7 +725,7 @@ PiecewiseSurvivalTime <- setRefClass("PiecewiseSurvivalTime",
 		.init = function(pwSurvTime) {
 			
 			.logDebug("pwSurvTime %s, %s", ifelse(is.numeric(pwSurvTime), 
-					.arrayToString(pwSurvTime), pwSurvTime), class(pwSurvTime[1]))
+				.arrayToString(pwSurvTime), pwSurvTime), .getClassName(pwSurvTime[1]))
 			.logDebug("lambda1 %s, %s", lambda1, .getParameterType("lambda1"))
 			.logDebug("lambda2 %s, %s", lambda2, .getParameterType("lambda2"))
 			
@@ -799,7 +800,7 @@ PiecewiseSurvivalTime <- setRefClass("PiecewiseSurvivalTime",
 									"'lambda2' can only be calculated if 'unique(lambda1 / hazardRatio^(1 / kappa))' ",
 									"result in a single value; current result = ", 
 									.arrayToString(round(lambda2, 4), vectorLookAndFeelEnabled = TRUE), 
-									" (delayed response is not allowed)")
+									" (e.g., delayed response is not allowed)")
 							}
 							
 							median2 <<- getMedianByLambda(lambda2, kappa)
@@ -1119,7 +1120,7 @@ PiecewiseSurvivalTime <- setRefClass("PiecewiseSurvivalTime",
 						"'hazardRatio' can only be calculated if 'unique(lambda1 / lambda2)' ",
 						"result in a single value; current result = ", 
 						.arrayToString(round(hr, 4), vectorLookAndFeelEnabled = TRUE), 
-						" (delayed response is not allowed)")
+						" (e.g., delayed response is not allowed)")
 				}
 				
 			}
@@ -1345,12 +1346,12 @@ AccrualTime <- setRefClass("AccrualTime",
 								accrualIntensityStr[i], "\n",
 								consoleOutputEnabled = consoleOutputEnabled)
 						}
-						else if (!maxNumberOfSubjectsIsUserDefined) {
+						else if (!maxNumberOfSubjectsIsUserDefined && !is.na(accrualIntensityStr[i]) && 
+                                accrualIntensityStr[i] != "NA") {
 							.cat("  ", accrualTimeStr[i], " - <=[?]: ",
 								accrualIntensityStr[i], "\n",
 								consoleOutputEnabled = consoleOutputEnabled)
 						}
-						
 					}
 					.cat("", consoleOutputEnabled = consoleOutputEnabled)
 				}
@@ -1404,7 +1405,7 @@ AccrualTime <- setRefClass("AccrualTime",
 					numberOfSubjects <- numberOfSubjects + 
 						(accrualTime[i + 1] - accrualTime[i]) * accrualIntensity[i]
 				}
-			}
+			}		
 			if (!isTRUE(all.equal(numberOfSubjects, maxNumberOfSubjects, tolerance = 1e-03)) && 
 					absoluteAccrualIntensityEnabled) {
 				stop(C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS, 
@@ -1420,7 +1421,7 @@ AccrualTime <- setRefClass("AccrualTime",
 				!absoluteAccrualIntensityEnabled) {
 				caseIsAllowed <- FALSE
 			} else if (!endOfAccrualIsUserDefined && !maxNumberOfSubjectsIsUserDefined && 
-				followUpTimeMustBeUserDefined && !absoluteAccrualIntensityEnabled) {
+					followUpTimeMustBeUserDefined && !absoluteAccrualIntensityEnabled) {
 				caseIsAllowed <- FALSE
 			}
 			if (!caseIsAllowed) {
@@ -1539,7 +1540,7 @@ AccrualTime <- setRefClass("AccrualTime",
 				caseIsAllowed <- FALSE
 				.cat("Case (#6):\n", sep = "", heading = 1, consoleOutputEnabled = consoleOutputEnabled)
 				.cat(prefix, "'maxNumberOfSubjects' and relative accrual intensity are given, ",
-					"absolute accrual intensity[x], end of accrual* and 'followUpTime'** shall be calculated\n", 
+					"absolute accrual intensity@, end of accrual* and 'followUpTime'** shall be calculated\n", 
 					consoleOutputEnabled = consoleOutputEnabled)
 				.cat(prefix, "Example: getAccrualTime(accrualTime = c(0, 6), ",
 					"accrualIntensity = c(0.22, 0.33), maxNumberOfSubjects = 1000)\n", 
@@ -1565,15 +1566,15 @@ AccrualTime <- setRefClass("AccrualTime",
 				caseIsAllowed <- FALSE
 				.cat("Case (#8):\n", sep = "", heading = 1, consoleOutputEnabled = consoleOutputEnabled)
 				.cat(prefix, "'followUpTime' and relative accrual intensity are given, ", 
-					"absolute accrual intensity[x], end of accrual and 'maxNumberOfSubjects' shall be calculated\n", 
+					"absolute accrual intensity@, end of accrual and 'maxNumberOfSubjects' shall be calculated\n", 
 					consoleOutputEnabled = consoleOutputEnabled)
 				.cat(prefix, "Example: getAccrualTime(accrualTime = c(0, 6), accrualIntensity = c(0.22, 0.33))\n", 
 					consoleOutputEnabled = consoleOutputEnabled)
 			}
 
-			.cat("\n", consoleOutputEnabled = consoleOutputEnabled)
+			#.cat("\n", consoleOutputEnabled = consoleOutputEnabled)
 			if (!caseIsAllowed) {
-				.cat(prefix, "[x] Cannot be calculated.\n", 
+				.cat(prefix, "(@) Cannot be calculated.\n", 
 					consoleOutputEnabled = consoleOutputEnabled)
 			}			
 			.cat(prefix, "(*) Can be calculated directly.\n", 
@@ -1626,7 +1627,7 @@ AccrualTime <- setRefClass("AccrualTime",
 			if (!endOfAccrualIsUserDefined && maxNumberOfSubjectsIsUserDefined &&
 					!absoluteAccrualIntensityEnabled) {
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
-					"the calulation of 'followUpTime' for given 'maxNumberOfSubjects' ",
+					"the calculation of 'followUpTime' for given 'maxNumberOfSubjects' ",
 					"and relative accrual intensities (< 1) ",
 					"can only be done if end of accrual is defined")
 			}
@@ -1635,7 +1636,7 @@ AccrualTime <- setRefClass("AccrualTime",
 			else if (!endOfAccrualIsUserDefined && !maxNumberOfSubjectsIsUserDefined && 
 					followUpTimeMustBeUserDefined && !absoluteAccrualIntensityEnabled) {
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
-					"the calulation of 'maxNumberOfSubjects' for given 'followUpTime' ",
+					"the calculation of 'maxNumberOfSubjects' for given 'followUpTime' ",
 					"and relative accrual intensities (< 1) ",
 					"can only be done if end of accrual is defined")
 			}
@@ -1917,32 +1918,36 @@ AccrualTime <- setRefClass("AccrualTime",
 					.setParameterType("remainingTime", C_PARAM_USER_DEFINED)
 				} else if (length(accrualTime) > 1) {
 					sampleSize <- .getSampleSize()
-					if (length(maxNumberOfSubjects) > 0 && !is.na(maxNumberOfSubjects) && 
-							maxNumberOfSubjects > 0 && maxNumberOfSubjects < sampleSize) {
-						if (length(accrualIntensity) == 1) {
-							.setParameterType("maxNumberOfSubjects", C_PARAM_USER_DEFINED)
-							accrualTime <<- 0
-							.calculateRemainingTime()
-						} else {
-							if (length(accrualTime) == length(accrualIntensity) + 1 && 
-									absoluteAccrualIntensityEnabled) {
-								stop(C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS, 
-									"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") disagrees with ",
-									"the defined accrual time and intensity: ",
-									.getFormula(), " = ", sampleSize)
+					if (!isTRUE(all.equal(sampleSize, maxNumberOfSubjects, tolerance = 1e-04))) {
+						if (length(maxNumberOfSubjects) == 1 && !is.na(maxNumberOfSubjects) && 
+								maxNumberOfSubjects > 0 && maxNumberOfSubjects < sampleSize) {
+							if (length(accrualIntensity) == 1 && length(accrualTime) == 1) {
+								.setParameterType("maxNumberOfSubjects", C_PARAM_USER_DEFINED)
+								accrualTime <<- 0
+								.calculateRemainingTime()
 							} else {
-								stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'maxNumberOfSubjects' (", 
-									maxNumberOfSubjects, ") ", "must be >= ", sampleSize)
+								if (length(accrualTime) == length(accrualIntensity) + 1 && 
+										absoluteAccrualIntensityEnabled) {
+									stop(C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS, 
+										"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") disagrees with ",
+										"the defined accrual time and intensity: ",
+										.getFormula(), " = ", sampleSize)
+								} else {
+									stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'maxNumberOfSubjects' (", 
+										maxNumberOfSubjects, ") ", "must be >= ", sampleSize)
+								}
 							}
-						}
-					} else {
-						if ((length(maxNumberOfSubjects) != 1 || is.na(maxNumberOfSubjects)) &&
+						} else {
+							if ((length(maxNumberOfSubjects) != 1 || is.na(maxNumberOfSubjects)) &&
 								absoluteAccrualIntensityEnabled) {
-							maxNumberOfSubjects <<- sampleSize
-							.setParameterType("maxNumberOfSubjects", C_PARAM_GENERATED)
+								maxNumberOfSubjects <<- sampleSize
+								.setParameterType("maxNumberOfSubjects", C_PARAM_GENERATED)
+							}
+							remainingTime <<- accrualTime[length(accrualTime)] - accrualTime[length(accrualTime) - 1]
+							.setParameterType("remainingTime", 
+								ifelse(!isTRUE(all.equal(0, remainingTime, tolerance = 1e-06)), 
+									C_PARAM_GENERATED, C_PARAM_NOT_APPLICABLE))
 						}
-						remainingTime <<- accrualTime[length(accrualTime)] - accrualTime[length(accrualTime) - 1]
-						.setParameterType("remainingTime", C_PARAM_GENERATED)
 					}
 				}
 			}
@@ -1987,6 +1992,9 @@ AccrualTime <- setRefClass("AccrualTime",
 				return(0)
 			}
 			
+			accrualTimeTemp <- accrualTime
+			accrualIntensityTemp <- accrualIntensity
+			
 			sampleSize <- 0
 			for (i in 2:length(accrualTime)) {
 				time <- accrualTime[i] - accrualTime[i - 1]
@@ -1994,71 +2002,81 @@ AccrualTime <- setRefClass("AccrualTime",
 				if (sampleSize >= maxNumberOfSubjects && 
 						length(accrualTime) == length(accrualIntensity)) {
 					
+					if (sampleSize > maxNumberOfSubjects) {
+						accrualTime <<- accrualTime[1:(i - 1)]
+					}
+
 					i2 <- i
 					if (length(accrualTime) == length(accrualIntensity) + 1) {
 						i2 <- i - 1
 					}
-					
-					if (.showWarnings) {
-						
-						n1 <- length(accrualTime) - i + 1
-						if (length(accrualTime) == length(accrualIntensity)) {
-							n1 <- n1 - 1
-						}
-						
-						if (n1 == 1) {
-							warning("Last accrual time value (", 
-								accrualTime[length(accrualTime)], ") ignored", call. = FALSE)
-						} else if (n1 > 1) {
-							warning("Last ", n1, " accrual time values (", 
-								.arrayToString(accrualTime[(length(accrualTime) - n1 + 1):length(accrualTime)]), 
-								") ignored", call. = FALSE)
-						}
-						
-						n2 <- length(accrualIntensity) - i2 + 1
-						if (n2 == 1) {
-							warning("Last accrual intensity value (", 
-								accrualIntensity[length(accrualIntensity)], ") ignored", call. = FALSE)
-						} else if (n2 > 1) {
-							warning("Last ", n2, " accrual intensity values (", 
-								.arrayToString(accrualIntensity[i2:length(accrualIntensity)]), 
-								") ignored", call. = FALSE)
-						}
-					}
-					accrualTime <<- accrualTime[1:(i - 1)]
 					accrualIntensity <<- accrualIntensity[1:(i2 - 1)]
+					
+					while (length(accrualTime) > length(accrualIntensity) + 1) {
+						accrualTime <<- accrualTime[1:(length(accrualTime) - 1)]
+					}
+					
 					sampleSize <- 0
 					if (length(accrualTime) > 1) {
 						sampleSize <- .getSampleSize()
 					}
+					
+					if (.showWarnings) {
+						n1 <- length(accrualTimeTemp) - length(accrualTime)
+						n2 <- length(accrualIntensityTemp) - length(accrualIntensity)
+						
+						if (n1 == 1) {
+							warning("Last accrual time value (", 
+								accrualTimeTemp[length(accrualTimeTemp)], ") ignored", call. = FALSE)
+						} else if (n1 > 1) {
+							warning("Last ", n1, " accrual time values (", 
+								.arrayToString(accrualTimeTemp[(length(accrualTimeTemp) - n1 + 1):length(accrualTimeTemp)]), 
+								") ignored", call. = FALSE)
+						}
+						
+						if (n2 == 1) {
+							warning("Last accrual intensity value (", 
+								accrualIntensityTemp[length(accrualIntensityTemp)], ") ignored", call. = FALSE)
+						} else if (n2 > 1) {
+							warning("Last ", n2, " accrual intensity values (", 
+								.arrayToString(accrualIntensityTemp[i2:length(accrualIntensityTemp)]), 
+								") ignored", call. = FALSE)
+						}
+					}
+					
 					return(sampleSize)
 				}
 			}
 			return(sampleSize)
 		},
 		
-		.calculateRemainingTime = function() {
+		.calculateRemainingTime = function(stopInCaseOfError = TRUE) {
 			.assertIsValidMaxNumberOfSubjects(maxNumberOfSubjects)
 			
-			if (length(accrualIntensity) == 1) {
-				lastAccrualIntensity <- accrualIntensity[1]
-				remainingSubjects <- maxNumberOfSubjects
-			} else {
-				sampleSize <- .calcSampleSize()
-				remainingSubjects <- maxNumberOfSubjects - sampleSize
-				if (remainingSubjects < 0) {
-					stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
-						"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") ",
-						"is too small for the defined accrual time (minimum = ", sampleSize, ")")
+			sampleSize <- .calcSampleSize()
+			remainingSubjects <- maxNumberOfSubjects - sampleSize
+			if (remainingSubjects < 0) {
+				if (!stopInCaseOfError) {
+					return(invisible())
 				}
+				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
+					"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") ",
+					"is too small for the defined accrual time (minimum = ", sampleSize, ")")
 			}
 			
 			lastAccrualIntensity <- accrualIntensity[length(accrualIntensity)]
 			remainingTime <<- remainingSubjects / lastAccrualIntensity
-			.setParameterType("remainingTime", C_PARAM_GENERATED)
-			accrualTime <<- c(accrualTime, accrualTime[length(accrualTime)] + remainingTime)
-			.setParameterType("accrualTime", C_PARAM_GENERATED)
+			.setParameterType("remainingTime", 
+				ifelse(!isTRUE(all.equal(0, remainingTime, tolerance = 1e-06)), 
+					C_PARAM_GENERATED, C_PARAM_NOT_APPLICABLE))
+			if (length(accrualTime) == length(accrualIntensity)) {
+				accrualTime <<- c(accrualTime, accrualTime[length(accrualTime)] + remainingTime)
+			}
+			#.setParameterType("accrualTime", C_PARAM_GENERATED)
 			if (any(accrualTime < 0)) {
+				if (!stopInCaseOfError) {
+					return(invisible())
+				}
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'maxNumberOfSubjects' (", maxNumberOfSubjects, ") ",
 					"is too small for the defined accrual time")
 			}
