@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 6652 $
+## |  Last changed: $Date: 2022-11-01 08:59:51 +0100 (Tue, 01 Nov 2022) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_logger.R
+NULL
+
 # @title
 # Get Analysis Results Rates
 #
@@ -52,7 +55,7 @@
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getAnalysisResultsRatesInverseNormal <- function(..., design,
@@ -211,7 +214,6 @@
     results$.setParameterType("testActions", C_PARAM_GENERATED)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -220,20 +222,7 @@
                 nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 pi1 = pi1, pi2 = pi2, iterations = iterations, seed = seed
             )
-            if (results$.conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- results$.conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-                results$.setParameterType("seed", results$.conditionalPowerResults$.getParameterType("seed"))
-                results$seed <- results$.conditionalPowerResults$seed
-                results$.setParameterType("iterations", results$.conditionalPowerResults$.getParameterType("iterations"))
-                results$iterations <- results$.conditionalPowerResults$iterations
-            } else {
-                results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- numeric(0)
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
             results$.conditionalPowerResults <- .getConditionalPowerRates(
                 stageResults = stageResults,
@@ -288,10 +277,9 @@
     .logProgress("Repeated p-values calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # final p-value
         startTime <- Sys.time()
-        finalPValue <- getFinalPValue(stageResults)
+        finalPValue <- getFinalPValue(stageResults, showWarnings = FALSE)
         results$finalPValues <- .getVectorWithFinalValueAtFinalStage(
             kMax = design$kMax,
             finalValue = finalPValue$pFinal, finalStage = finalPValue$finalStage
@@ -351,7 +339,7 @@
         stage = NA_integer_, userFunctionCallEnabled = FALSE) {
     .assertIsDatasetRates(dataInput)
     .assertIsValidThetaH0DataInput(thetaH0, dataInput)
-    directionUpper <- .assertIsValidDirectionUpper(directionUpper, design$sided,
+    .assertIsValidDirectionUpper(directionUpper, design$sided,
         userFunctionCallEnabled = userFunctionCallEnabled
     )
     .assertIsSingleLogical(normalApproximation, "normalApproximation")
@@ -639,7 +627,7 @@
         return(.getRepeatedConfidenceIntervalsRatesFisher(design = design, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getRootThetaRates <- function(..., design, dataInput, stage, directionUpper, normalApproximation,
@@ -705,13 +693,33 @@
     repeatedConfidenceIntervals <- matrix(NA_real_, 2, design$kMax)
     for (k in (1:stage)) {
         startTime <- Sys.time()
+        if (criticalValues[k] < C_QNORM_MAXIMUM) {
+            # finding upper and lower RCI limits through root function
+            if (dataInput$getNumberOfGroups() == 1) {
+                if (dataInput$overallEvents[k] == 0) {
+                    repeatedConfidenceIntervals[1, k] <- 0
+                } else {
+                    repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
+                        design = design, dataInput = dataInput, stage = k,
+                        directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
+                        firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                        acceptResultsOutOfTolerance = TRUE,
+                        callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+                    )
+                }
 
-        # finding upper and lower RCI limits through root function
-
-        if (dataInput$getNumberOfGroups() == 1) {
-            if (dataInput$overallEvents[k] == 0) {
-                repeatedConfidenceIntervals[1, k] <- 0
-            } else {
+                if (dataInput$overallEvents[k] == dataInput$overallSampleSizes[k]) {
+                    repeatedConfidenceIntervals[2, k] <- 1
+                } else {
+                    repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
+                        design = design, dataInput = dataInput, stage = k,
+                        directionUpper = FALSE, normalApproximation = normalApproximation,
+                        firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                        acceptResultsOutOfTolerance = TRUE,
+                        callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
+                    )
+                }
+            } else if (dataInput$getNumberOfGroups() == 2) {
                 repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
                     design = design, dataInput = dataInput, stage = k,
                     directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
@@ -719,62 +727,41 @@
                     acceptResultsOutOfTolerance = TRUE,
                     callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
                 )
-            }
 
-            if (dataInput$overallEvents[k] == dataInput$overallSampleSizes[k]) {
-                repeatedConfidenceIntervals[2, k] <- 1
-            } else {
                 repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
                     design = design, dataInput = dataInput, stage = k,
                     directionUpper = FALSE, normalApproximation = normalApproximation,
                     firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
                     acceptResultsOutOfTolerance = TRUE,
-                    callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
+                    callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
                 )
             }
-        } else if (dataInput$getNumberOfGroups() == 2) {
-            repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
-                design = design, dataInput = dataInput, stage = k,
-                directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
-                firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-                acceptResultsOutOfTolerance = TRUE,
-                callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-            )
 
-            repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
-                design = design, dataInput = dataInput, stage = k,
-                directionUpper = FALSE, normalApproximation = normalApproximation,
-                firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-                acceptResultsOutOfTolerance = TRUE,
-                callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-            )
-        }
+            # adjustment for binding futility bounds
+            if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
 
+                futilityCorr[k] <- .getRootThetaRates(
+                    design = design, dataInput = dataInput, stage = k - 1,
+                    directionUpper = directionUpper, normalApproximation = normalApproximation,
+                    firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
+                    acceptResultsOutOfTolerance = TRUE,
+                    callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
+                )
 
-        # adjustment for binding futility bounds
-        if (k > 1 && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
-            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
-
-            futilityCorr[k] <- .getRootThetaRates(
-                design = design, dataInput = dataInput, stage = k - 1,
-                directionUpper = directionUpper, normalApproximation = normalApproximation,
-                firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
-                acceptResultsOutOfTolerance = TRUE,
-                callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
-            )
-
-            if (directionUpper) {
-                repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
-            } else {
-                repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
+                if (directionUpper) {
+                    repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
+                } else {
+                    repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
+                }
             }
+            .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
         }
-        .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
-    }
 
-    if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
-            repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
-        repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
+        if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
+                repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
+            repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
+        }
     }
 
     return(repeatedConfidenceIntervals)
@@ -853,7 +840,6 @@
 }
 
 .calculateThetaH1 <- function(stageResults, pi1, pi2, stage, kMax, nPlanned, allocationRatioPlanned) {
-
     # Shifted decision region for use in getGroupSequentialProbabilities
     # Inverse normal method
     condError <- getConditionalRejectionProbabilities(stageResults = stageResults)[stage]
@@ -1125,22 +1111,9 @@
         results$iterations <- cp$iterations
         results$seed <- cp$seed
         results$simulated <- cp$simulated
-        if (results$simulated) {
-            results$.setParameterType(
-                "iterations",
-                ifelse(is.null(.getOptionalArgument("iterations", ...)),
-                    C_PARAM_DEFAULT_VALUE, C_PARAM_USER_DEFINED
-                )
-            )
-            results$.setParameterType(
-                "seed",
-                ifelse(is.null(.getOptionalArgument("seed", ...)),
-                    C_PARAM_DEFAULT_VALUE, C_PARAM_USER_DEFINED
-                )
-            )
-        }
+        .updateParameterTypeOfIterationsAndSeed(results, ...)
     } else {
-        .stopWithWrongDesignMessage(stageResults$.design)
+        .stopWithWrongDesignMessage(stageResults$.design, inclusiveConditionalDunnett = FALSE)
     }
 
     results$nPlanned <- cp$nPlanned
@@ -1424,8 +1397,13 @@
         }
     }
 
-    finalConfidenceIntervalGeneral <- sort(finalConfidenceIntervalGeneral)
-    finalConfidenceInterval <- sort(finalConfidenceInterval)
+    if (!any(is.na(finalConfidenceIntervalGeneral))) {
+        finalConfidenceIntervalGeneral <- sort(finalConfidenceIntervalGeneral)
+    }
+    if (!any(is.na(finalConfidenceInterval))) {
+        finalConfidenceInterval <- sort(finalConfidenceInterval)
+    }
+
     if (dataInput$getNumberOfGroups() == 1) {
         finalConfidenceInterval[1] <- max(0, finalConfidenceInterval[1])
         finalConfidenceInterval[2] <- min(1, finalConfidenceInterval[2])
@@ -1435,6 +1413,11 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0,
+        directionUpper = directionUpper,
+        normalApproximation = normalApproximation,
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = finalConfidenceIntervalGeneral,
@@ -1608,6 +1591,11 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0,
+        directionUpper = directionUpper,
+        normalApproximation = normalApproximation,
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = finalConfidenceIntervalGeneral,
@@ -1649,6 +1637,11 @@
     }
 
     return(list(
+        stage = stage,
+        thetaH0 = thetaH0,
+        directionUpper = directionUpper,
+        normalApproximation = normalApproximation,
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiased = medianUnbiased,
         finalConfidenceInterval = finalConfidenceInterval
@@ -1704,5 +1697,5 @@
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
