@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5684 $
-## |  Last changed: $Date: 2022-01-05 12:27:24 +0100 (Mi, 05 Jan 2022) $
-## |  Last changed by: $Author: wassmer $
+## |  File version: $Revision: 6649 $
+## |  Last changed: $Date: 2022-10-28 10:46:32 +0200 (Fri, 28 Oct 2022) $
+## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_logger.R
+NULL
+
 .calcMeansVariancesTestStatistics <- function(dataInput, subset, stage, thetaH0, stratifiedAnalysis, varianceOption) {
     .assertIsSingleInteger(stage, "stage")
     .assertIsSingleNumber(thetaH0, "thetaH0")
@@ -290,7 +293,6 @@
         paste("stage ", (1:kMax), sep = "")
     )
 
-
     subsets <- .createSubsetsByGMax(gMax = gMax, stratifiedInput = dataInput$isStratified(), subsetIdPrefix = "S")
     for (k in 1:stage) {
         for (population in 1:gMax) {
@@ -420,7 +422,7 @@
         return(.getAnalysisResultsMeansFisherEnrichment(design = design, dataInput = dataInput, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
 .getAnalysisResultsMeansInverseNormalEnrichment <- function(...,
@@ -485,6 +487,9 @@
     )
 
     results <- AnalysisResultsEnrichmentFisher(design = design, dataInput = dataInput)
+    .setValueAndParameterType(results, "iterations", as.integer(iterations), C_ITERATIONS_DEFAULT)
+    .setValueAndParameterType(results, "seed", seed, NA_real_)
+    
     results <- .getAnalysisResultsMeansEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
         intersectionTest = intersectionTest, stage = stage, directionUpper = directionUpper,
@@ -555,33 +560,23 @@
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
-            conditionalPowerResults <- .getConditionalPowerMeansEnrichment(
+            results$.conditionalPowerResults <- .getConditionalPowerMeansEnrichment(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, assumedStDevs = assumedStDevs, iterations = iterations, seed = seed
             )
-            if (conditionalPowerResults$simulated) {
-                results$conditionalPowerSimulated <- conditionalPowerResults$conditionalPower
-                results$.setParameterType("conditionalPower", C_PARAM_NOT_APPLICABLE)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_GENERATED)
-            } else {
-                results$conditionalPower <- conditionalPowerResults$conditionalPower
-                results$conditionalPowerSimulated <- matrix(numeric(0))
-                results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
-                results$.setParameterType("conditionalPowerSimulated", C_PARAM_NOT_APPLICABLE)
-            }
+            .synchronizeIterationsAndSeed(results)
         } else {
-            conditionalPowerResults <- .getConditionalPowerMeansEnrichment(
+            results$.conditionalPowerResults <- .getConditionalPowerMeansEnrichment(
                 stageResults = stageResults,
                 stage = stage, nPlanned = nPlanned, allocationRatioPlanned = allocationRatioPlanned,
                 thetaH1 = thetaH1, assumedStDevs = assumedStDevs
             )
-            results$conditionalPower <- conditionalPowerResults$conditionalPower
+            results$conditionalPower <- results$.conditionalPowerResults$conditionalPower
             results$.setParameterType("conditionalPower", C_PARAM_GENERATED)
         }
-        results$thetaH1 <- matrix(conditionalPowerResults$thetaH1, ncol = 1)
-        results$assumedStDevs <- matrix(conditionalPowerResults$assumedStDevs, ncol = 1)
-        results$.conditionalPowerResults <- conditionalPowerResults
+        results$thetaH1 <- matrix(results$.conditionalPowerResults$thetaH1, ncol = 1)
+        results$assumedStDevs <- matrix(results$.conditionalPowerResults$assumedStDevs, ncol = 1)
         .logProgress("Conditional power calculated", startTime = startTime)
 
         # CRP - conditional rejection probabilities
@@ -753,7 +748,7 @@
     for (k in stages) {
         startTime <- Sys.time()
         for (population in 1:gMax) {
-            if (!is.na(stageResults$testStatistics[population, k])) {
+            if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
 
                 # finding maximum upper and minimum lower bounds for RCIs
                 thetaLow <- .getUpperLowerThetaMeansEnrichment(
@@ -804,7 +799,7 @@
                 )
 
                 # adjustment for binding futility bounds
-                if (k > 1 && conditionFunction(bounds[k - 1], border) & design$bindingFutility) {
+				if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                     parameterName <- ifelse(.isTrialDesignFisher(design),
                         "singleStepAdjustedPValues", firstParameterName
                     )
@@ -939,10 +934,12 @@
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsMeansEnrichmentInverseNormal(design = design, ...))
     }
+    
     if (.isTrialDesignFisher(design)) {
         return(.getRepeatedConfidenceIntervalsMeansEnrichmentFisher(design = design, ...))
     }
-    .stopWithWrongDesignMessage(design)
+    
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
 #
@@ -998,6 +995,7 @@
         assumedStDevs, stageResults, stage,
         results = results
     )
+    .assertIsValidAssumedStDevs(assumedStDevs, gMax)
     thetaH1 <- .assertIsValidThetaH1ForEnrichment(thetaH1, stageResults, stage, results = results)
     if (length(thetaH1) != 1 && length(thetaH1) != gMax) {
         stop(
@@ -1008,15 +1006,6 @@
             ), .arrayToString(thetaH1), gMax)
         )
     }
-    if (length(assumedStDevs) != 1 && length(assumedStDevs) != gMax) {
-        stop(
-            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            sprintf(paste0(
-                "length of 'assumedStDevs' (%s) ",
-                "must be equal to 'gMax' (%s) or 1"
-            ), .arrayToString(assumedStDevs), gMax)
-        )
-    }
 
     if (length(assumedStDevs) == 1) {
         results$assumedStDevs <- rep(assumedStDevs, gMax)
@@ -1176,7 +1165,7 @@
     criticalValues <- design$criticalValues
     weightsFisher <- .getWeightsFisher(design)
 
-    # results$conditionalPower <- matrix(NA_real_, nrow = gMax, ncol = kMax)
+    results$conditionalPower <- matrix(NA_real_, nrow = gMax, ncol = kMax)
 
     results$iterations <- as.integer(iterations)
     results$.setParameterType("iterations", C_PARAM_USER_DEFINED)
