@@ -13,11 +13,14 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5594 $
-## |  Last changed: $Date: 2021-11-26 15:24:35 +0100 (Fr, 26 Nov 2021) $
+## |  File version: $Revision: 6585 $
+## |  Last changed: $Date: 2022-09-23 14:23:08 +0200 (Fr, 23 Sep 2022) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
+#' @include f_core_utilities.R
+NULL
+
 #
 #  @title
 #  Get Multi-Armed Analysis Results
@@ -79,7 +82,7 @@
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not implemented yet")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
 #
@@ -104,7 +107,7 @@
         return(.getStageResultsSurvivalMultiArm(design = design, dataInput = dataInput, userFunctionCallEnabled = TRUE, ...))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not supported")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not supported")
 }
 
 # Get Repeated Confidence Intervals for multi-arm case
@@ -134,7 +137,7 @@
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", class(dataInput), "' is not implemented yet")
+    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
 }
 
 #
@@ -175,7 +178,7 @@
 
     stop(
         C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-        class(stageResults$.dataInput), "' is not implemented yet"
+        .getClassName(stageResults$.dataInput), "' is not implemented yet"
     )
 }
 
@@ -248,7 +251,7 @@
             if (!all(is.na(stageResults$separatePValues[indices[i, ] == 1, k]))) {
                 if ((intersectionTest == "Dunnett") || (intersectionTest == "SpiessensDebois")) {
                     sigma <- 1
-                    if (grepl("MultiArm", class(stageResults))) {
+                    if (grepl("MultiArm", .getClassName(stageResults))) {
                         if (.isStageResultsMultiArmSurvival(stageResults)) {
                             allocationRatiosSelected <- as.numeric(na.omit(
                                 dataInput$getAllocationRatios(stage = k, group = 1:gMax)[indices[i, ] == 1]
@@ -431,7 +434,7 @@ getClosedCombinationTestResults <- function(stageResults) {
     result <- .performClosedCombinationTest(stageResults = stageResults)
     return(ClosedCombinationTestResults(
         .design = result$.design,
-        .enrichment = grepl("Enrichment", class(stageResults)),
+        .enrichment = grepl("Enrichment", .getClassName(stageResults)),
         intersectionTest = result$intersectionTest,
         separatePValues = result$separatePValues,
         indices = result$indices,
@@ -662,7 +665,7 @@ getClosedCombinationTestResults <- function(stageResults) {
 #' @family analysis functions
 #' @details
 #' For performing the conditional Dunnett test the design must be defined through the function
-#' \code{\link{getDesignConditionalDunnett}}.\cr
+#' \code{\link[=getDesignConditionalDunnett]{getDesignConditionalDunnett()}}.\cr
 #' See Koenig et al. (2008) and Wassmer & Brannath (2016), chapter 11 for details of the test procedure.
 #'
 #' @template return_object_closed_combination_test_results
@@ -686,7 +689,7 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     result <- .getClosedConditionalDunnettTestResults(stageResults = stageResults, design = design, stage = stage)
     return(ClosedCombinationTestResults(
         .design = result$.design,
-        .enrichment = grepl("Enrichment", class(stageResults)),
+        .enrichment = grepl("Enrichment", .getClassName(stageResults)),
         intersectionTest = result$intersectionTest,
         indices = result$indices,
         separatePValues = result$separatePValues,
@@ -1189,6 +1192,6 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
 
     stop(
         C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-        class(stageResults$.dataInput), "' is not implemented yet"
+        .getClassName(stageResults$.dataInput), "' is not implemented yet"
     )
 }
