@@ -13,12 +13,13 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 5655 $
-## |  Last changed: $Date: 2021-12-15 07:19:53 +0100 (Wed, 15 Dec 2021) $
+## |  File version: $Revision: 6414 $
+## |  Last changed: $Date: 2022-07-15 09:17:18 +0200 (Fr, 15 Jul 2022) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_simulation_utilities.R
+#' @include f_core_utilities.R
 NULL
 
 .getIndicesOfSelectedSubsets <- function(gMax) {
@@ -37,17 +38,6 @@ NULL
     return(indexList)
 }
 
-.createSelectedSubsetsTheoretical <- function(stage, selectedPopulations) {
-    gMax <- nrow(selectedPopulations)
-    selectedVector <- rep(FALSE, 2^(gMax - 1))
-
-    indices <- .getIndicesOfSelectedSubsets(gMax)
-    for (i in 1:length(indices)) {
-        selectedVector[i] <- any(selectedPopulations[indices[[i]], stage])
-    }
-    return(selectedVector)
-}
-
 .createSelectedSubsets <- function(stage, selectedPopulations) {
     gMax <- nrow(selectedPopulations)
     selectedVector <- rep(FALSE, 2^(gMax - 1))
@@ -127,7 +117,7 @@ NULL
             stop(msg, "the output must be a logical vector of length 'gMax' (", gMax, ")")
         }
         if (!is.logical(selectedPopulations)) {
-            stop(msg, "the output must be a logical vector (is ", class(selectedPopulations), ")")
+            stop(msg, "the output must be a logical vector (is ", .getClassName(selectedPopulations), ")")
         }
     }
     return(selectedPopulations)
@@ -286,7 +276,6 @@ NULL
 
 .createSimulationResultsEnrichmentObject <- function(...,
         design,
-        populations,
         effectList,
         intersectionTest,
         stratifiedAnalysis = NA,
@@ -368,21 +357,14 @@ NULL
     } else if (endpoint == "survival") {
         simulationResults <- SimulationResultsEnrichmentSurvival(design, showStatistics = showStatistics)
     }
-
-    .assertIsSinglePositiveInteger(populations, "populations", naAllowed = TRUE, validateType = FALSE)
-    if (is.na(populations)) {
-        if (is.null(effectList) || is.null(effectList[["subGroups"]])) {
-            .assertIsSinglePositiveInteger(populations, "populations", naAllowed = FALSE, validateType = FALSE)
-        }
-        populations <- .getGMaxFromSubGroups(effectList$subGroups)
+    
+    effectList <- .getValidatedEffectList(effectList, endpoint = endpoint)
+    gMax <- .getGMaxFromSubGroups(effectList$subGroups)
+    if (gMax > 4) {
+        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'populations' (", gMax, ") must not exceed 4")
     }
 
-    if (populations > 4) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'populations' (", populations, ") max not exceed 4")
-    }
-
-    gMax <- populations
-    kMax <- design$kMax
+    .assertIsValidThreshold(threshold, activeArms = gMax)
 
     intersectionTest <- intersectionTest[1]
     .assertIsValidIntersectionTestEnrichment(design, intersectionTest)
@@ -395,7 +377,7 @@ NULL
         )
     }
 
-    typeOfSelection <- .assertIsValidTypeOfSelection(typeOfSelection, rValue, epsilonValue, populations)
+    typeOfSelection <- .assertIsValidTypeOfSelection(typeOfSelection, rValue, epsilonValue, gMax)
     if (length(typeOfSelection) == 1 && typeOfSelection == "userDefined" &&
             !is.null(threshold) && length(threshold) == 1 && threshold != -Inf) {
         warning("'threshold' (", threshold, ") will be ignored because 'typeOfSelection' = \"userDefined\"", call. = FALSE)
@@ -411,16 +393,17 @@ NULL
     if (endpoint %in% c("rates", "survival")) {
         .setValueAndParameterType(simulationResults, "directionUpper", directionUpper, TRUE)
     }
+    
+    if (!stratifiedAnalysis && endpoint %in% c("means", "survival")) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "For testing ", endpoint, ifelse(endpoint == "survival", " designs", ""), 
+            ", only stratified analysis is supported"
+        )
+    }
 
-    effectList <- .getValidatedEffectList(effectList, gMax = gMax)
+    kMax <- design$kMax
     if (endpoint == "means") {
-        if (!stratifiedAnalysis) {
-            stop(
-                C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-                "For testing means, only stratified analysis can be selected"
-            )
-        }
-
         stDevH1 <- .ignoreParameterIfNotUsed(
             "stDevH1", stDevH1, kMax > 1,
             "design is fixed ('kMax' = 1)", "Assumed standard deviation"
@@ -432,10 +415,6 @@ NULL
             "piTreatmentH1", piTreatmentH1, kMax > 1,
             "design is fixed ('kMax' = 1)", "Assumed active rate(s)"
         )
-# 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(piTreatmentH1)) {
-# 			warning("'piTreatmentH1' will be ignored because neither 'conditionalPower' nor ",
-# 				"'calcSubjectsFunction' is defined", call. = FALSE)
-# 		}
         .setValueAndParameterType(simulationResults, "piTreatmentH1", piTreatmentH1, NA_real_)
 
         .assertIsSingleNumber(piControlH1, "piControlH1", naAllowed = TRUE)
@@ -444,18 +423,8 @@ NULL
             "piControlH1", piControlH1, kMax > 1,
             "design is fixed ('kMax' = 1)", "Assumed control rate(s)"
         )
-# 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(piControlH1)) {
-# 			warning("'piControlH1' will be ignored because neither 'conditionalPower' nor ",
-# 				"'calcSubjectsFunction' is defined", call. = FALSE)
-# 		}
         .setValueAndParameterType(simulationResults, "piControlH1", piControlH1, NA_real_)
     } else if (endpoint == "survival") {
-        if (!stratifiedAnalysis) {
-            stop(
-                C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-                "For survival designs, only stratified analysis is possible"
-            )
-        }
         .assertIsIntegerVector(plannedEvents, "plannedEvents", validateType = FALSE)
         if (length(plannedEvents) != kMax) {
             stop(
@@ -469,8 +438,6 @@ NULL
         .setValueAndParameterType(simulationResults, "plannedEvents", plannedEvents, NA_real_)
     }
 
-    .assertIsValidThreshold(threshold, gMax)
-
     if (endpoint %in% c("means", "rates")) {
         .assertIsValidPlannedSubjects(plannedSubjects, kMax) # means + rates only
     }
@@ -737,17 +704,17 @@ NULL
     }
     .setValueAndParameterType(simulationResults, "adaptations", adaptations, rep(TRUE, kMax - 1))
 
-    simulationResults$.setParameterType("effectList", C_PARAM_USER_DEFINED)
-
     simulationResults$effectList <- effectList
-
+    simulationResults$.setParameterType("effectList", C_PARAM_USER_DEFINED)
+    
+    simulationResults$populations <- as.integer(gMax)
+    simulationResults$.setParameterType("populations", C_PARAM_DERIVED)
+    
     .setValueAndParameterType(
         simulationResults, "stratifiedAnalysis", stratifiedAnalysis,
         C_STRATIFIED_ANALYSIS_DEFAULT
     )
 
-    .setValueAndParameterType(simulationResults, "populations", as.integer(populations), C_POPULATIONS_DEFAULT)
-
     if (typeOfSelection != "userDefined") {
         .setValueAndParameterType(simulationResults, "threshold", threshold, -Inf)
         .setValueAndParameterType(simulationResults, "epsilonValue", epsilonValue, NA_real_)
@@ -758,7 +725,7 @@ NULL
     .setValueAndParameterType(simulationResults, "successCriterion", successCriterion, C_SUCCESS_CRITERION_DEFAULT)
     .setValueAndParameterType(simulationResults, "effectMeasure", effectMeasure, C_EFFECT_MEASURE_DEFAULT)
 
-    warning("Simulation of enrichment designs is experimental and hence not fully validated", call. = FALSE)
+    warning("Simulation of enrichment designs is experimental and hence not fully validated (see www.rpact.com/experimental)", call. = FALSE)
     
     return(simulationResults)
 }
