@@ -13,8 +13,8 @@
 ## | 
 ## |  Contact us for information about our services: info@rpact.com
 ## | 
-## |  File version: $Revision: 5577 $
-## |  Last changed: $Date: 2021-11-19 09:14:42 +0100 (Fr, 19 Nov 2021) $
+## |  File version: $Revision: 6784 $
+## |  Last changed: $Date: 2023-01-31 10:11:06 +0100 (Di, 31 Jan 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## | 
 
@@ -24,7 +24,7 @@
 #' 
 #' @description
 #' rpact (R Package for Adaptive Clinical Trials) is a comprehensive package that enables 
-#' the design and analysis of confirmatory adaptive group sequential designs. 
+#' the design, simulation, and analysis of confirmatory adaptive group sequential designs. 
 #' Particularly, the methods described in the recent monograph by Wassmer and Brannath
 #' (published by Springer, 2016) are implemented. It also comprises advanced methods for sample
 #' size calculations for fixed sample size designs incl., e.g., sample size calculation for survival
@@ -71,13 +71,11 @@
 #' @import utils
 #' @import graphics
 #' @import tools
+#' @importFrom rlang .data
 #' 
 "_PACKAGE"
 #> [1] "_PACKAGE"
 
-.onLoad <- function(libname, pkgname) {
-}
-
 .onAttach <- function(libname, pkgname) {
 	if (grepl("^\\d\\.\\d\\.\\d\\.\\d{4,4}$", packageVersion("rpact"))) {
 		packageStartupMessage(paste0("rpact developer version ", packageVersion("rpact"), " loaded"))
