@@ -14,13 +14,13 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_core_output_formats.R
-## |  Creation date: 08 December 2021, 09:08:44
-## |  File version: $Revision$
-## |  Last changed: $Date$
-## |  Last changed by: $Author$
+## |  Creation date: 06 February 2023, 12:11:55
+## |  File version: $Revision: 6801 $
+## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |  
 
-context("Testing the Output Format Functions")
+test_plan_section("Testing the Output Format Functions")
 
 
 test_that("'.formatPValues'", {
@@ -129,6 +129,5 @@ test_that("'.getDecimalPlaces'", {
 
 	## Comparison of the results of integer object 'x' with expected results
 	expect_equal(x, c(15, 5))
-
 })
 
