@@ -14,13 +14,13 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_core_utilities.R
-## |  Creation date: 08 December 2021, 09:08:44
-## |  File version: $Revision$
-## |  Last changed: $Date$
-## |  Last changed by: $Author$
+## |  Creation date: 06 February 2023, 12:11:55
+## |  File version: $Revision: 6801 $
+## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
+## |  Last changed by: $Author: pahlke $
 ## |  
 
-context("Testing Result Object Print Output")
+test_plan_section("Testing Result Object Print Output")
 
 
 test_that("The output does not contain any issues", {
@@ -34,7 +34,7 @@ test_that("The output does not contain any issues", {
 
 })
 
-context("Testing Core Utility Functions")
+test_plan_section("Testing Core Utility Functions")
 
 
 test_that("'getValidatedInformationRates': 'informationRates' must be generated correctly based on specified 'kMax'", {
@@ -118,8 +118,8 @@ test_that("'getValidatedInformationRates': 'informationRates' must be set correc
 	design23 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignGroupSequential")
 	expect_equal(.getValidatedInformationRates(design23), c(0.16, 0.32, 0.48, 0.64, 1), tolerance = 1e-07)
 
-	design24 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignGroupSequential")
-	expect_equal(.getValidatedInformationRates(design24), c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), tolerance = 1e-07)
+	design24 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignGroupSequential")
+	expect_equal(.getValidatedInformationRates(design24), c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), tolerance = 1e-07)
 
 	design25 <- getTestDesign(informationRates = 1, designClass = "TrialDesignInverseNormal")
 	expect_equal(.getValidatedInformationRates(design25), 1, tolerance = 1e-07)
@@ -136,8 +136,8 @@ test_that("'getValidatedInformationRates': 'informationRates' must be set correc
 	design29 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignInverseNormal")
 	expect_equal(.getValidatedInformationRates(design29), c(0.16, 0.32, 0.48, 0.64, 1), tolerance = 1e-07)
 
-	design30 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignInverseNormal")
-	expect_equal(.getValidatedInformationRates(design30), c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), tolerance = 1e-07)
+	design30 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignInverseNormal")
+	expect_equal(.getValidatedInformationRates(design30), c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), tolerance = 1e-07)
 
 	design31 <- getTestDesign(informationRates = 1, designClass = "TrialDesignFisher")
 	expect_equal(.getValidatedInformationRates(design31), 1, tolerance = 1e-07)
@@ -154,8 +154,8 @@ test_that("'getValidatedInformationRates': 'informationRates' must be set correc
 	design35 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignFisher")
 	expect_equal(.getValidatedInformationRates(design35), c(0.16, 0.32, 0.48, 0.64, 1), tolerance = 1e-07)
 
-	design36 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignFisher")
-	expect_equal(.getValidatedInformationRates(design36), c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), tolerance = 1e-07)
+	design36 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignFisher")
+	expect_equal(.getValidatedInformationRates(design36), c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), tolerance = 1e-07)
 
 
 
@@ -229,7 +229,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	design56 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignGroupSequential")
 	expect_equal(design56$kMax, 5, tolerance = 1e-07)
 
-	design57 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignGroupSequential")
+	design57 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignGroupSequential")
 	expect_equal(design57$kMax, 6, tolerance = 1e-07)
 
 	design58 <- getTestDesign(informationRates = 1, designClass = "TrialDesignInverseNormal")
@@ -247,7 +247,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	design62 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignInverseNormal")
 	expect_equal(design62$kMax, 5, tolerance = 1e-07)
 
-	design63 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignInverseNormal")
+	design63 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignInverseNormal")
 	expect_equal(design63$kMax, 6, tolerance = 1e-07)
 
 	design64 <- getTestDesign(informationRates = 1, designClass = "TrialDesignFisher")
@@ -265,7 +265,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	design68 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignFisher")
 	expect_equal(design68$kMax, 5, tolerance = 1e-07)
 
-	design69 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignFisher")
+	design69 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignFisher")
 	expect_equal(design69$kMax, 6, tolerance = 1e-07)
 
 
@@ -620,7 +620,7 @@ test_that("'getValidatedInformationRates': 'futilityBounds' must be set correctl
 	design177 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignGroupSequential")
 	expect_equal(.getValidatedFutilityBounds(design177), c(-6, -6, -6, -6), tolerance = 1e-07)
 
-	design178 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignGroupSequential")
+	design178 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignGroupSequential")
 	expect_equal(.getValidatedFutilityBounds(design178), c(-6, -6, -6, -6, -6), tolerance = 1e-07)
 
 	design179 <- getTestDesign(informationRates = c(0.11428571, 0.22857143, 0.34285714, 0.45714286, 0.57142857, 0.68571429, 1), designClass = "TrialDesignGroupSequential")
@@ -677,7 +677,7 @@ test_that("'getValidatedInformationRates': 'futilityBounds' must be set correctl
 	design196 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignInverseNormal")
 	expect_equal(.getValidatedFutilityBounds(design196), c(-6, -6, -6, -6), tolerance = 1e-07)
 
-	design197 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignInverseNormal")
+	design197 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignInverseNormal")
 	expect_equal(.getValidatedFutilityBounds(design197), c(-6, -6, -6, -6, -6), tolerance = 1e-07)
 
 	design198 <- getTestDesign(informationRates = c(0.11428571, 0.22857143, 0.34285714, 0.45714286, 0.57142857, 0.68571429, 1), designClass = "TrialDesignInverseNormal")
@@ -737,7 +737,7 @@ test_that("'getValidatedInformationRates': 'futilityBounds' must be set correctl
 	design215 <- getTestDesign(informationRates = c(0.16, 0.32, 0.48, 0.64, 1), designClass = "TrialDesignFisher")
 	expect_equal(.getValidatedAlpha0Vec(design215), c(1, 1, 1, 1), tolerance = 1e-07)
 
-	design216 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignFisher")
+	design216 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignFisher")
 	expect_equal(.getValidatedAlpha0Vec(design216), c(1, 1, 1, 1, 1), tolerance = 1e-07)
 
 
@@ -941,7 +941,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	.getValidatedFutilityBounds(design263)
 	expect_equal(design263$kMax, 5, tolerance = 1e-07)
 
-	design264 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignGroupSequential")
+	design264 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignGroupSequential")
 	.getValidatedFutilityBounds(design264)
 	expect_equal(design264$kMax, 6, tolerance = 1e-07)
 
@@ -1017,7 +1017,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	.getValidatedFutilityBounds(design282)
 	expect_equal(design282$kMax, 5, tolerance = 1e-07)
 
-	design283 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignInverseNormal")
+	design283 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignInverseNormal")
 	.getValidatedFutilityBounds(design283)
 	expect_equal(design283$kMax, 6, tolerance = 1e-07)
 
@@ -1096,7 +1096,7 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 	.getValidatedAlpha0Vec(design301)
 	expect_equal(design301$kMax, 5, tolerance = 1e-07)
 
-	design302 <- getTestDesign(informationRates = c(0.13333333, 0.26666667, 0.4, 0.53333333, 0.66666667, 1), designClass = "TrialDesignFisher")
+	design302 <- getTestDesign(informationRates = c(0.1333, 0.26667, 0.4, 0.53333, 0.8667, 1), designClass = "TrialDesignFisher")
 	.getValidatedAlpha0Vec(design302)
 	expect_equal(design302$kMax, 6, tolerance = 1e-07)
 
@@ -1104,17 +1104,46 @@ test_that("'getValidatedInformationRates': 'kMax' must be set correctly based on
 
 })
 
-context("Testing Utilities")
+test_plan_section("Testing Utilities")
 
 
-test_that("Testing '.toCapitalized'", {
-	expect_equal(.toCapitalized("zip code"), "Zip Code")	
-	expect_equal(.toCapitalized("state of the art"), "State of the Art")	
-	expect_equal(.toCapitalized("final and count"), "Final and Count")	
+test_that("Testing '.moveValue'", {
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "B"), c("A", "B", "E", "C", "D"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "A"), c("A", "E", "B", "C", "D"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "E"), c("B", "C", "D", "E", "A"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "E"), c("A", "B", "C", "D", "E"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "A"), c("A", "B", "C", "D", "E"))
+	expect_equal(.moveValue(c("A"), "A", "A"), c("A"))
 
 })
 
-test_that("Testing '.equalsRegexpIgnoreCase'	", {
+test_that("Testing '.toCapitalized'", {
+
+	expect_equal(.toCapitalized("zip code"), "Zip Code")
+	expect_equal(.toCapitalized("state of the art"), "State of the Art")
+	expect_equal(.toCapitalized("final and count"), "Final and Count")
+	expect_equal(.toCapitalized("Hazard Ratio"), "Hazard Ratio") 
+	expect_equal(.toCapitalized("hazard ratio function"), "Hazard Ratio Function")
+
+})
+
+test_that("Testing '.formatCamelCase'", {
+
+	expect_equal(.formatCamelCase("hazardRatio", title = TRUE), "Hazard Ratio")
+	expect_equal(.formatCamelCase("hazardRatio and informationRates", title = TRUE), "Hazard Ratio and Information Rates")
+	expect_equal(.formatCamelCase("hazardRatio", title = FALSE), "hazard ratio")
+	expect_equal(.formatCamelCase(" hazardRatio ", title = TRUE), " Hazard Ratio ")
+	expect_equal(.formatCamelCase("Hazard", title = TRUE), "Hazard")
+	expect_equal(.formatCamelCase("hazard", title = TRUE), "Hazard")
+	expect_equal(.formatCamelCase("hazard", title = FALSE), "hazard")
+	expect_equal(.formatCamelCase("Hazard", title = FALSE), "hazard")
+	expect_equal(.formatCamelCase("Hazard Ratio", title = TRUE), "Hazard Ratio")
+	expect_equal(.formatCamelCase(" hazard ratio ", title = TRUE), " Hazard Ratio ")
+	expect_equal(.formatCamelCase("HazardRatio", title = FALSE), "hazard ratio")
+
+})
+
+test_that("Testing '.equalsRegexpIgnoreCase'", {
 
 	expect_equal(.equalsRegexpIgnoreCase("stage2", "^stages?$"), FALSE)
 	expect_equal(.equalsRegexpIgnoreCase("stage", "^stages?$"), TRUE)
@@ -1125,7 +1154,7 @@ test_that("Testing '.equalsRegexpIgnoreCase'	", {
 	expect_equal(.equalsRegexpIgnoreCase(" stages", "^stages?$"), FALSE)
 
 	expect_equal(.equalsRegexpIgnoreCase("stages2", "stages?"), TRUE)
-	expect_equal(.equalsRegexpIgnoreCase("1stage2", "stages?"), TRUE)	
+	expect_equal(.equalsRegexpIgnoreCase("1stage2", "stages?"), TRUE)
 
 })
 
@@ -1158,10 +1187,10 @@ test_that("Testing 'isUndefinedArgument' and 'isValidArgument'", {
 	expect_error(.isDefinedArgument(notExistingTestVariable, argumentExistsValidationEnabled = FALSE))
 	expect_error(.isDefinedArgument(notExistingTestVariable))
 
-	#skip_if_translated()
-	#expect_error(.isDefinedArgument(notExistingTestVariable),
-	#	paste0("Missing argument: the object 'notExistingTestVariable' has not been defined anywhere. ",
-	#	"Please define it first, e.g., run 'notExistingTestVariable <- 1'"), fixed = TRUE)
+	# skip_if_translated()
+	# expect_error(.isDefinedArgument(notExistingTestVariable),
+	# 	paste0("Missing argument: the object 'notExistingTestVariable' has not been defined anywhere. ",
+	# 	"Please define it first, e.g., run 'notExistingTestVariable <- 1'"), fixed = TRUE)
 
 })
 
@@ -1212,6 +1241,24 @@ test_that("Testing '.arrayToString'", {
 
 })
 
+test_that("Testing '.getQNorm'", {
+
+	expect_equal(sign(.getQNorm(1)), sign(qnorm(1)))
+	expect_equal(.getQNorm(1 - 1e-12), qnorm(1 - 1e-12))
+	expect_equal(sign(.getQNorm(0)), sign(qnorm(0)))
+	expect_equal(.getQNorm(1e-12), qnorm(1e-12))
+
+})
+
+test_that("Testing '.getOneMinusQNorm'", {
+
+	expect_equal(sign(.getOneMinusQNorm(1)), sign(1 - qnorm(1)))
+	expect_equal(.getOneMinusQNorm(1 - 1e-12), -qnorm(1 - 1e-12))
+	expect_equal(sign(.getOneMinusQNorm(0)), sign(1 - qnorm(0)))
+	expect_equal(.getOneMinusQNorm(1e-12), -qnorm(1e-12))
+
+})
+
 test_that("Testing '.getInputProducingZeroOutput'", {
 
 	tolerance <- 1e-05
@@ -1247,82 +1294,123 @@ test_that("Testing '.getOneDimensionalRoot'", {
 
 	.skipTestIfDisabled()
 
-	tolerance <- 1e-08	
+	tolerance <- 1e-08
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 2}, lower = -1, upper = 1, tolerance = tolerance), NA_real_)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 2}, lower = -1, upper = 1, tolerance = tolerance), NA_real_)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 2
+	}, lower = -1, upper = 1, tolerance = tolerance), NA_real_)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 2
+	}, lower = -1, upper = 1, tolerance = tolerance), NA_real_)
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 1 - tolerance}, lower = -1, upper = 1, tolerance = tolerance), 1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 1 + tolerance}, lower = -1, upper = 1, tolerance = tolerance), -1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 1}, lower = -1, upper = 1, tolerance = tolerance), 1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 1}, lower = -1, upper = 1, tolerance = tolerance), -1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 1 - tolerance
+	}, lower = -1, upper = 1, tolerance = tolerance), 1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 1 + tolerance
+	}, lower = -1, upper = 1, tolerance = tolerance), -1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 1
+	}, lower = -1, upper = 1, tolerance = tolerance), 1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 1
+	}, lower = -1, upper = 1, tolerance = tolerance), -1)
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 1}, lower = 0, upper = 1, tolerance = tolerance), 1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 1}, lower = tolerance, upper = 1, tolerance = tolerance), 1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 1}, lower = -1, upper = 0, tolerance = tolerance), -1)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 1}, lower = -1, upper = 1- tolerance, tolerance = tolerance), -1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 1
+	}, lower = 0, upper = 1, tolerance = tolerance), 1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 1
+	}, lower = tolerance, upper = 1, tolerance = tolerance), 1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 1
+	}, lower = -1, upper = 0, tolerance = tolerance), -1)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 1
+	}, lower = -1, upper = 1 - tolerance, tolerance = tolerance), -1)
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 3}, lower = 1, upper = 5, tolerance = tolerance), 3)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 3}, lower = -5, upper = -1, tolerance = tolerance), -3)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 3
+	}, lower = 1, upper = 5, tolerance = tolerance), 3)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 3
+	}, lower = -5, upper = -1, tolerance = tolerance), -3)
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {3 * x - 700}, lower = 100, upper = 1000, tolerance = tolerance), 233.33333333)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {3 * x + 700}, lower = -1000, upper = -100, tolerance = tolerance), -233.33333333)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    3 * x - 700
+	}, lower = 100, upper = 1000, tolerance = tolerance), 233.33333333)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    3 * x + 700
+	}, lower = -1000, upper = -100, tolerance = tolerance), -233.33333333)
 
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x - 4}, lower = -10, upper = 10), 4, tolerance = tolerance)
-	expect_equal(.getOneDimensionalRoot(f = function(x) {x + 4}, lower = -10, upper = 10), -4, tolerance = tolerance)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x - 4
+	}, lower = -10, upper = 10), 4, tolerance = tolerance)
+	expect_equal(.getOneDimensionalRoot(f = function(x) {
+	    x + 4
+	}, lower = -10, upper = 10), -4, tolerance = tolerance)
 
 	dataExample1 <- getDataset(
-		overallEvents = c(33, 55, 129),
-		overallAllocationRatios = c(1, 1, 4),
-		overallLogRanks = c(1.02, 1.38, 2.2)
+	    overallEvents = c(33, 55, 129),
+	    overallAllocationRatios = c(1, 1, 4),
+	    overallLogRanks = c(1.02, 1.38, 2.2)
 	)
 	design1 <- getDesignGroupSequential(kMax = 3, alpha = 0.025, typeOfDesign = "WT", deltaWT = 0.25)
-	result1 <- getRepeatedConfidenceIntervals(design1, dataExample1, stage = 3) 
+	result1 <- getRepeatedConfidenceIntervals(design1, dataExample1, stage = 3)
 
 	## Comparison of the results of matrixarray object 'result1' with expected results
 	expect_equal(result1[1, ], c(0.54923831, 0.77922365, 1.0261298), tolerance = 1e-07)
 	expect_equal(result1[2, ], c(3.7041718, 2.7014099, 2.5669073), tolerance = 1e-07)
 
-	design2 <- getDesignGroupSequential(kMax = 3, alpha = 0.025, informationRates = c(0.4, 0.7, 1),
-		typeOfDesign = "WT", deltaWT = 0.35)
+	design2 <- getDesignGroupSequential(
+	    kMax = 3, alpha = 0.025, informationRates = c(0.4, 0.7, 1),
+	    typeOfDesign = "WT", deltaWT = 0.35
+	)
 	dataExample2 <- getDataset(
-		overallN2 = c(30,80,100),
-		overallN1 = c(30,80,100),
-		overallEvents2 = c(10,25,36),
-		overallEvents1 = c(14,35,53))
-	result2 <- getRepeatedConfidenceIntervals(design = design2, dataInput = dataExample2, 
-		stage = 3, normalApproximation = TRUE, directionUpper = TRUE)
+	    overallN2 = c(30, 80, 100),
+	    overallN1 = c(30, 80, 100),
+	    overallEvents2 = c(10, 25, 36),
+	    overallEvents1 = c(14, 35, 53)
+	)
+	result2 <- getRepeatedConfidenceIntervals(
+	    design = design2, dataInput = dataExample2,
+	    stage = 3, normalApproximation = TRUE, directionUpper = TRUE
+	)
 
 	## Comparison of the results of matrixarray object 'result2' with expected results
-	expect_equal(result2[1, ], c(-0.17491854, -0.048575312, 0.01895796), tolerance = 1e-07)
-	expect_equal(result2[2, ], c(0.41834402, 0.29168781, 0.31353692), tolerance = 1e-07)
+	expect_equal(result2[1, ], c(-0.17491833, -0.048575314, 0.018957987), tolerance = 1e-07)
+	expect_equal(result2[2, ], c(0.41834377, 0.2916876, 0.31353674), tolerance = 1e-07)
 
-	design3 <- getDesignInverseNormal(kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),  
-		typeOfDesign = "WT", deltaWT = 0.25)
+	design3 <- getDesignInverseNormal(
+	    kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),
+	    typeOfDesign = "WT", deltaWT = 0.25
+	)
 	dataExample3 <- getDataset(
-		events1 = c(7,57),
-		events2 = c(7,57),
-		n1 = c(30,300),
-		n2 = c(30,300)
-	) 
+	    events1 = c(7, 57),
+	    events2 = c(7, 57),
+	    n1 = c(30, 300),
+	    n2 = c(30, 300)
+	)
 	result3 <- getRepeatedConfidenceIntervals(design3, dataExample3)
 
 	## Comparison of the results of matrixarray object 'result3' with expected results
-	expect_equal(result3[1, ], c(-0.26729325, -0.071745936), tolerance = 1e-07)
-	expect_equal(result3[2, ], c(0.26729325, 0.071745764), tolerance = 1e-07)
+	expect_equal(result3[1, ], c(-0.26729325, -0.071746001), tolerance = 1e-07)
+	expect_equal(result3[2, ], c(0.26729325, 0.071746001), tolerance = 1e-07)
 
-	design4 <- getDesignInverseNormal(kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),  
-		typeOfDesign = "WT", deltaWT = 0.25)
+	design4 <- getDesignInverseNormal(
+	    kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),
+	    typeOfDesign = "WT", deltaWT = 0.25
+	)
 	dataExample4 <- getDataset(
-		events1 = c(4,55),
-		events2 = c(4,46),
-		n1 = c(30,300),
-		n2 = c(30,300))
+	    events1 = c(4, 55),
+	    events2 = c(4, 46),
+	    n1 = c(30, 300),
+	    n2 = c(30, 300)
+	)
 	result4 <- getRepeatedConfidenceIntervals(design4, dataExample4)
 
 	## Comparison of the results of matrixarray object 'result4' with expected results
-	expect_equal(result4[1, ], c(-0.23589449, -0.043528443), tolerance = 1e-07)
+	expect_equal(result4[1, ], c(-0.23589449, -0.043528426), tolerance = 1e-07)
 	expect_equal(result4[2, ], c(0.23589449, 0.088472144), tolerance = 1e-07)
-
 })
 
